# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: worm.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Event_pb2 as Event__pb2
import Command_pb2 as Command__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='worm.proto',
  package='',
  syntax='proto3',
  serialized_pb=_b('\n\nworm.proto\x1a\x0b\x45vent.proto\x1a\rCommand.proto\"7\n\x08Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04\x63ode\x18\x03 \x01(\x05\"\x1d\n\x0cSubscription\x12\r\n\x05topic\x18\x01 \x01(\t2\\\n\x0bWormService\x12%\n\x0cIssueCommand\x12\x08.Command\x1a\t.Response\"\x00\x12&\n\tSubscribe\x12\r.Subscription\x1a\x06.Event\"\x00\x30\x01\x42\x08Z\x06golangb\x06proto3')
  ,
  dependencies=[Event__pb2.DESCRIPTOR,Command__pb2.DESCRIPTOR,])




_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='Response.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='Response.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code', full_name='Response.code', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=97,
)


_SUBSCRIPTION = _descriptor.Descriptor(
  name='Subscription',
  full_name='Subscription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='Subscription.topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=128,
)

DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['Subscription'] = _SUBSCRIPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSE,
  __module__ = 'worm_pb2'
  # @@protoc_insertion_point(class_scope:Response)
  ))
_sym_db.RegisterMessage(Response)

Subscription = _reflection.GeneratedProtocolMessageType('Subscription', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIPTION,
  __module__ = 'worm_pb2'
  # @@protoc_insertion_point(class_scope:Subscription)
  ))
_sym_db.RegisterMessage(Subscription)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\006golang'))

_WORMSERVICE = _descriptor.ServiceDescriptor(
  name='WormService',
  full_name='WormService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=130,
  serialized_end=222,
  methods=[
  _descriptor.MethodDescriptor(
    name='IssueCommand',
    full_name='WormService.IssueCommand',
    index=0,
    containing_service=None,
    input_type=Command__pb2._COMMAND,
    output_type=_RESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='WormService.Subscribe',
    index=1,
    containing_service=None,
    input_type=_SUBSCRIPTION,
    output_type=Event__pb2._EVENT,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORMSERVICE)

DESCRIPTOR.services_by_name['WormService'] = _WORMSERVICE

# @@protoc_insertion_point(module_scope)
